import { LoaderHelper } from '@/helpers/loader-helper'
import { LogHelper } from '@/helpers/log-helper'

import train from '../train/train'
import generateHttpApiKey from '../generate/generate-http-api-key'

import setupDotenv from './setup-dotenv'
import setupCore from './setup-core'
import setupSkillsConfig from './setup-skills-config'
// import setupPythonPackages from './setup-python-packages'

// Do not load ".env" file because it is not created yet

/**
 * Main entry to set up Leon
 */
;(async () => {
  try {
    await setupDotenv()
    LoaderHelper.start()
    await Promise.all([setupCore(), setupSkillsConfig()])
    // TODO: download Python bridge archive; unpack it; remove archive
    // TODO: download TCP server archive; unpack it; remove archive
    // await setupPythonPackages()
    LoaderHelper.stop()
    await generateHttpApiKey()
    LoaderHelper.start()
    await train()

    LogHelper.default('')
    LogHelper.success('Hooray! Leon is installed and ready to go!')
    LoaderHelper.stop()
  } catch (e) {
    LogHelper.error(e)
    LoaderHelper.stop()
  }
})()
